#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://emhsoft.com/dh.html
# source           : http://emhsoft.com/dh/Dragon_Hunt-3.56.tar.gz

# Package name
NAME="Dragon_Hunt"
# Package version
VERSION="3.56"
# Source code URL
SOURCE="http://emhsoft.com/dh/Dragon_Hunt-$VERSION.tar.gz"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="noarch"
BUILD="54.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: Dragon_Hunt - A small but fun RPG.
$NAME:
$NAME: Investigate the rumors of monsters attacking a small town. (Hint:
$NAME: the rumors are true). There are two modules (games) included in
$NAME: this package: Dark Ages and Dragon Hunt.
$NAME: 
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

if [ -f Dragon_Hunt-3.56-use-homedir.patch ]; then
	echo "Patch already here, no need to download";
else
 	echo "Downloading patch"
	wget -c http://pnboy.pinguix.com/gapan/games/Dragon_Hunt/Dragon_Hunt-3.56-use-homedir.patch
fi

# Check to see if an icon is present. If it's not, download it
if [ -f $NAME.png ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/$NAME.png
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/dragonhunt.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Dragon Hunt
Comment=Arcade Games
Exec=dragonhunt
Terminal=false
Type=Application
Categories=Game;RolePlaying;
Icon=Dragon_Hunt
EOF

# Create a launching script
mkdir $PKG/usr/bin
cat > $PKG/usr/bin/dragonhunt << EOF
cd /usr/share/Dragon_Hunt
./Dragon_Hunt_Linux
EOF
chmod a+x $PKG/usr/bin/dragonhunt

cd $NAME-$VERSION
# Patch for user homedir
patch -p1 < $CWD/Dragon_Hunt-3.56-use-homedir.patch

# No building, just copying
mkdir -p $PKG/usr/share/$NAME
cp -a ./* $PKG/usr/share/$NAME
# We don't need the setup.py file
rm $PKG/usr/share/$NAME/setup.py

# Symlink Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $PKG/usr/doc/$NAME-$VERSION
ln -sf ../../share/$NAME/README.txt README.txt
ln -sf ../../share/$NAME/docs docs

# Copy icon to the right place
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
cp -a $CWD/$NAME.png $PKG/usr/share/icons/hicolor/48x48/apps

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG

cat >  $NAME-$VERSION-$ARCH-$BUILD.src << EOF
http://emhsoft.com/dh/Dragon_Hunt-3.56.tar.gz
http://pnboy.pinguix.com/gapan/games/Dragon_Hunt/build-Dragon_Hunt.sh
http://pnboy.pinguix.com/gapan/games/Dragon_Hunt/Dragon_Hunt-3.56-use-homedir.patch
http://pnboy.pinguix.com/gapan/games/Dragon_Hunt/Dragon_Hunt.png
EOF
